@@ -6,12 +6,11 @@ use Log::Dispatch::Email;
 
 use base qw( Log::Dispatch::Email );
 
-use Carp ();
 use Mail::Send;
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.19 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = '1.19';
 
 1;
 
@@ -28,6 +27,7 @@ sub send_email
     # Does this ever work for this module?
     $msg->set('From', $self->{from}) if $self->{from};
 
+    local $?;
     eval
     {
 	my $fh = $msg->open
@@ -86,12 +86,12 @@ The name of the object (not the filename!).  Required.
 =item * min_level ($)
 
 The minimum logging level this object will accept.  See the
-Log::Dispatch documentation for more information.  Required.
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
 
 =item * max_level ($)
 
 The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation for more information.  This is not
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
 required.  By default the maximum is the highest possible level (which
 means functionally that the object has no maximum).
 
