@@ -13,7 +13,7 @@ use vars qw[ $VERSION ];
 
 use Carp ();
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.26 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = '1.26';
 
 1;
 
@@ -212,12 +212,12 @@ The name of the object (not the filename!).  Required.
 =item * min_level ($)
 
 The minimum logging level this object will accept.  See the
-Log::Dispatch documentation for more information.  Required.
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
 
 =item * max_level ($)
 
 The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation for more information.  This is not
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
 required.  By default the maximum is the highest possible level (which
 means functionally that the object has no maximum).
 
